# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
try:
    from django.db import migrations
except ImportError:
    pass
else:
    class Migration(migrations.Migration):

        dependencies = [
            ('contenttypes', '0002_remove_content_type_name'),
        ]

        operations = [
            migrations.CreateModel(
                name='Choice',
                fields=[
                    ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                    ('object_id', models.PositiveIntegerField()),
                    ('choice', models.CharField(max_length=200)),
                    ('votes', models.IntegerField(default=0)),
                    ('content_type', models.ForeignKey(to='contenttypes.ContentType')),
                ],
            ),
            migrations.CreateModel(
                name='Poll',
                fields=[
                    ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                    ('question', models.CharField(max_length=200)),
                    ('pub_date', models.DateTimeField(verbose_name=b'date published')),
                ],
            ),
        ]



from django.db import models

"""
Module-level doctest.

    >>> Zoo
    <class 'project.zoo.models.Zoo'>
    >>> 1 + 1
    2
"""

def func():
    """
    Function-level test
        >>> 1+3
        4
    """
    pass
# Create your models here.
class Zoo(models.Model):
    """
    Class-level doctest

    >>> Zoo
    <class 'project.zoo.models.Zoo'>
    >>> 1 + 1
    2
    >>> Zoo.objects.all()
    []
    >>> z = Zoo(name='Bronx')
    >>> z.save()
    >>> z
    <Zoo: Bronx>
    >>> Zoo.objects.all()
    [<Zoo: Bronx>]
    """
    name = models.CharField(max_length=100)

    def __str__(self):
        """
        Function in class test
        >>> 1 + 2
        3
        """
        return self.name




from django.test import TransactionTestCase

class SeleniumTestCase(TransactionTestCase):

    def test_simple(self):
        driver = self.driver
        driver.get('http://www.google.com')
        self.assertEqual(driver.title, 'Google')

    def test_simple_with_ctrl_c(self):
        driver = self.driver
        driver.get('http://www.google.com')
        #raise KeyboardInterrupt('test')



from django.test.testcases import TestCase

from nosedjangotests.polls.models import Choice


class AAAFixtureTestCase(TestCase):
    fixtures = [
        'choices',
    ]

    def test_to_load_fixtures(self):
        self.assertEqual(Choice.objects.count(), 1)


class BBBNoFixturesFollowingWithFixturesTestCase(TestCase):
    def test_no_data_left_over_from_previous_fixture(self):
        self.assertEqual(Choice.objects.count(), 0)



DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    # ('Your Name', 'your_email@domain.com'),
)

MANAGERS = ADMINS

DATABASE_ENGINE = 'sqlite3'
DATABASE_NAME = 'nosedjango'
DATABASE_USER = 'root'
DATABASE_PASSWORD = ''
DATABASE_HOST = ''
DATABASE_PORT = ''

TIME_ZONE = 'America/Chicago'
LANGUAGE_CODE = 'en-us'
SITE_ID = 1

USE_I18N = True
MEDIA_ROOT = ''
MEDIA_URL = ''

ADMIN_MEDIA_PREFIX = '/media/'
SECRET_KEY = 'w9*+(qevfn*j2959ikv-_7kj7ivptt#8&n*gy0o&ktisx@%rzt'

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
)

ROOT_URLCONF = 'nosedjangotests.urls'

TEMPLATE_DIRS = (
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',

    'nosedjangotests.polls',
)



# We have two test classes because we want to induce a race condition
# and ensure that the database is always reset between test methods

from zoo.models import *

class TestDBRace1(object):
    def setup(self):
        assert Zoo.objects.count() == 0

    def test1(self):
        obj = Zoo.objects.create(name='sample1')
        assert Zoo.objects.count() == 1
        assert Zoo.objects.all()[0].name == 'sample1'


class TestDBRace2(object):
    def setup(self):
        assert Zoo.objects.count() == 0

    def test1(self):
        obj = Zoo.objects.create(name='sample2')
        assert Zoo.objects.count() == 1
        assert Zoo.objects.all()[0].name == 'sample2'



import os.path
import shutil

from nosedjango.plugins.base_plugin import Plugin


class FileStoragePlugin(Plugin):
    """
    Set up a test file system so you're writing to a specific directory for
    your testing.
    """
    name = 'django-testfs'

    def beforeTestSetup(self, settings, setup_test_environment, connection):
        """
        Create a unique directory for media for use during testing. We want a
        unique directory because we empty the dir after every test to guard
        against side effects. This also allows the use of multiprocess for
        testing without worrying about different processes interacting via
        the storage system.
        """
        settings.DEFAULT_FILE_STORAGE = 'django.core.files.storage.FileSystemStorage'  # noqa
        from django.core.files.storage import default_storage

        token = self.get_unique_token()

        default_storage.location = os.path.join(
            settings.MEDIA_ROOT,
            "_nj/%s" % token)
        default_storage.base_url = os.path.join(
            settings.MEDIA_URL,
            '_nj/%s/' % token)

    def afterRollback(self, settings):
        """
        After every test, we want to empty the media directory so that media
        left over from one test doesn't affect a later test.
        """
        self.clear_test_media()

    def clear_test_media(self):
        from django.core.files.storage import default_storage
        try:
            shutil.rmtree(default_storage.location)
        except OSError:
            # If nothing was added to storage, this directory will be empty
            # and will error out
            pass



import os
from nose.config import ConfigError

from nosedjango.plugins.base_plugin import Plugin

try:
    djkombu_installed = True
    import djkombu  # noqa
except ImportError:
    djkombu_installed = False


class CeleryPlugin(Plugin):
    """
    Configure Celery to run locally for testing and optionally use a database
    backend so you don't have to install RabbitMQ to test.
    """
    name = 'django-celery'

    def __init__(self, *args, **kwargs):
        super(CeleryPlugin, self).__init__(*args, **kwargs)

        self.use_djkombu = False

    def options(self, parser, env=None):
        if env is None:
            env = os.environ
        parser.add_option(
            '--dbbacked-celery',
            dest='use_djkombu',
            action='store_true',
            default=False,
            help=(
                'Use django-kombu for database-backed Celery. Alleviates the '
                'need to install rabbitmq.'
            ),
        )

        super(CeleryPlugin, self).options(parser, env)

    def configure(self, options, config):
        self.use_djkombu = options.use_djkombu

        if self.use_djkombu and not djkombu_installed:
            # Trying to use django-kombu, but it's not actually installed
            raise ConfigError(
                "django-kombu must be installed in order to use --dbbacked-celery",  # noqa
            )

        super(CeleryPlugin, self).configure(options, config)

    def beforeTestSetup(self, settings, setup_test_environment, connection):
        settings.CELERY_ALWAYS_EAGER = True
        settings.CELERY_RESULTS_BACKEND = 'database'

        if self.use_djkombu:
            settings.INSTALLED_APPS += 'djkombu'
            settings.BROKER_BACKEND = "djkombu.transport.DatabaseTransport"



from project.zoo.models import *

class TestFixture1(object):
    fixtures = ['f1.json']

    def test_count(self):
        assert Zoo.objects.count() == 1
        assert Zoo.objects.get(id=1).name == 'f1'


class TestFixture2(object):
    fixtures = ['f2.json']
    def test_count(self):
        assert Zoo.objects.count() == 1
        assert Zoo.objects.get(id=1).name == 'f2'



from django.test import TestCase

from nosedjangotests.polls.models import Poll
from nosedjangotests.polls.tests.test1 import _test_fixtures_2


class BaseCase(TestCase):

    def __init__(self, *args, **kwargs):
        inits = ['polls1.json', 'polls2.json']
        self.fixtures = list(inits + getattr(self, 'fixtures', []))
        super(BaseCase, self).__init__(*args, **kwargs)

    def setUp(self):
        pass


class FixtureBleed1TestCase(BaseCase):
    fixtures = [
        'polls1.json',
    ]

    def test_fixtures_loaded(self):
        num_polls = Poll.objects.all().count()
        # Ignore the evil __init__ overriding of self.fixtures
        self.assertEqual(num_polls, 1)


class FixtureBleed2TestCase(TestCase):
    fixtures = ['polls1.json']

    def test_fixture_bleed(self):
        num_polls = Poll.objects.all().count()
        self.assertEqual(num_polls, 1)


class AltersBleed2TestCase(TestCase):
    fixtures = ['polls2.json']

    def test_bleeding_alteration(self):
        _test_fixtures_2(self)



# -*- coding: utf-8 -*-
try:
    from south.utils import datetime_utils as datetime
    from south.db import db
    from south.v2 import SchemaMigration
except ImportError:
    class SchemaMigration(object):
        pass
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Poll'
        db.create_table('polls_poll', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('question', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('pub_date', self.gf('django.db.models.fields.DateTimeField')()),
        ))
        db.send_create_signal('polls', ['Poll'])

        # Adding model 'Choice'
        db.create_table('polls_choice', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('choice', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('votes', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('polls', ['Choice'])


    def backwards(self, orm):
        # Deleting model 'Poll'
        db.delete_table('polls_poll')

        # Deleting model 'Choice'
        db.delete_table('polls_choice')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'polls.choice': {
            'Meta': {'object_name': 'Choice'},
            'choice': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'votes': ('django.db.models.fields.IntegerField', [], {'default': '0'})
        },
        'polls.poll': {
            'Meta': {'object_name': 'Poll'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'pub_date': ('django.db.models.fields.DateTimeField', [], {}),
            'question': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        }
    }

    complete_apps = ['polls']



"""
nosedjango cranks up the awesome for your Django project by giving you all the
testing goodness of the Nose ecosystem. Use multiprocess, xunit, coverage, etc
or even write your own plugin that hooks in to the NoseDjango plugin system (a
plugin with a plugin system!)
"""

VERSION = (1, 0, 6, '')

__version__ = ".".join(map(str, VERSION[:-1]))
__release__ = ".".join(map(str, VERSION))
__author__ = "Wes Winham"
__contact__ = "winhamwr@gmail.com"
__homepage__ = "http://github.com/nosedjango/nosedjango/"
__docformat__ = "restructuredtext"
